package com.xhkjedu.sexam.service.paperstudent;

import com.xhkjedu.sexam.mapper.paper.EPaperQtypeMapper;
import com.xhkjedu.sexam.mapper.paperstudent.EPaperStudentMapper;
import com.xhkjedu.sexam.mapper.paperstudent.EPaperStudentQuestionMapper;
import com.xhkjedu.sexam.model.paper.EPaperQtype;
import com.xhkjedu.sexam.model.paper.EPaperQtypeQuestion;
import com.xhkjedu.sexam.model.paperstudent.EPaperStudent;
import com.xhkjedu.sexam.model.paperstudent.EPaperStudentQuestion;
import com.xhkjedu.sexam.vo.paperstudent.EPaperStudentVo;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description 学生试卷信息
 * @Author WN
 * Date 2022/7/26 14:00
 **/
@Service
public class EPaperStudentService {
    @Resource
    private EPaperStudentMapper ePaperStudentMapper;
    @Resource
    private EPaperQtypeMapper ePaperQtypeMapper;
    @Resource
    private EPaperStudentQuestionMapper ePaperStudentQuestionMapper;

    /**
     * @Description  学生进行中考试列表
     * @Param [eps]
     * @Return java.util.List<java.util.Map>
     * @Author wn
     * @Date 2022/7/27 10:35
     **/
    public List<Map> listExamPapersForStudent(EPaperStudent eps){
        return ePaperStudentMapper.listExamPapersForStudent(eps.getStudentid());
    }

    /** 学生已结束考试列表
     * @Description
     * @Param [eps]
     * @Return java.util.List<java.util.Map>
     * @Author wn
     * @Date 2022/7/27 11:34
     **/
    public List<Map> listExamsEndForStudent(EPaperStudent eps){
        return ePaperStudentMapper.listExamsEndForStudent(eps.getStudentid());
    }

    /**
     * @Description 开始考试(andorid)
     * @Param [eps]
     * @Return java.util.Map
     * @Author wn
     * @Date 2022/7/27 11:48
     **/
    public List<Map> startPaperForAndroid(EPaperStudent eps){
        Integer epsid = eps.getEpsid();
        //获取试卷基本信息
        EPaperStudentVo psvo = ePaperStudentMapper.getExamSubjectByEpsid(epsid);
        Integer ptype = psvo.getPtype();

        List<Map> questions = null;
        if(ptype == 1){
            //题库试卷试题
            questions = ePaperStudentMapper.listStuPaperQuestionsForAndroid(epsid);
        }else{
            questions = ePaperStudentMapper.listStuPaperFjQuestionsForAndroid(epsid);
        }
        //判断是否生成学生试卷，未生成则需要生成，如果已生成直接返回
        if(questions == null || questions.size() == 0){

            //保存试卷关联信息
            savePaperStudentQuestion(psvo);
            //保存后重新获取返回
            if(ptype == 1){
                questions = ePaperStudentMapper.listStuPaperQuestionsForAndroid(epsid);
            }else{
                questions = ePaperStudentMapper.listStuPaperFjQuestionsForAndroid(epsid);
            }
        }
        return questions;
    }

    //保存学生试卷关联信息
    private void savePaperStudentQuestion(EPaperStudentVo psvo){
        //生成学生试卷
        List<EPaperQtypeQuestion> pqlist = ePaperQtypeMapper.listQuestionsByEpid(psvo.getEpid());

        List<EPaperStudentQuestion> psqlist = new ArrayList<>();
        for(EPaperQtypeQuestion q : pqlist){
            EPaperStudentQuestion sq = new EPaperStudentQuestion();
            sq.setClassid(psvo.getClassid());
            sq.setStudentid(psvo.getStudentid());
            sq.setEpid(psvo.getEpid());
            sq.setEpsid(psvo.getEpsid());
            sq.setEptqid(q.getEptqid());
            sq.setQuestionid(q.getQuestionid());
            sq.setQn(q.getQn());
            sq.setQorder(q.getQorder());
            sq.setQscore(q.getScore());
            sq.setAnswered(0);
            sq.setConverted(0);
            sq.setChecked(0);
            sq.setStuscore(0.0);
            psqlist.add(sq);
        }
        ePaperStudentQuestionMapper.insertList(psqlist);//保存试卷
    }

    /**
     * @Description 开始考试（web）
     * @Param [eps]
     * @Return java.util.List<java.util.Map>
     * @Author wn
     * @Date 2022/7/27 15:36
     **/
    public EPaperStudentVo startPaperForWeb(EPaperStudent eps){
        Integer epsid = eps.getEpsid();
        //获取试卷基本信息
        EPaperStudentVo psvo = ePaperStudentMapper.getExamSubjectByEpsid(epsid);
        Integer ptype = psvo.getPtype();

        List<EPaperQtype> questions = null;
        if(ptype == 1){
            //题库试卷试题
            questions = ePaperStudentMapper.listStuPaperQuestionsForWeb(epsid);
        }else{
            questions = ePaperStudentMapper.listStuPaperFjQuestionsForWeb(epsid);
        }
        //判断是否生成学生试卷，未生成则需要生成，如果已生成直接返回
        if(questions == null || questions.size() == 0){
            //保存试卷关联信息
            savePaperStudentQuestion(psvo);
            //保存后重新获取返回
            if(ptype == 1){
                questions = ePaperStudentMapper.listStuPaperQuestionsForWeb(epsid);
            }else{
                questions = ePaperStudentMapper.listStuPaperFjQuestionsForWeb(epsid);
            }
        }
        psvo.setQtypelist(questions);
        return psvo;
    }

}
